@@ -11,7 +11,7 @@ Software::License::LGPL_2_1 - GNU Lesser General Public License, Version 2.1
 
 sub name { 'The GNU Lesser General Public License, Version 2.1, February 1999' }
 sub url  { 'http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt' }
-sub meta_yml_name { 'lgpl' }
+sub meta_name { 'lgpl' }
 
 1;
 __DATA__
