@@ -23,7 +23,7 @@ Calling this method in scalar context is a fatal error.
 my $_v = qr/(?:v(?:er(?:sion|\.))(?: |\.)?)/i;
 my @phrases = (
   "under the same (?:terms|license) as perl $_v?6" => [],
-  'under the same (?:terms|license) as perl'    => 'Perl_5',
+  'under the same (?:terms|license) as (?:the )?perl'    => 'Perl_5',
   'affero g'                                    => 'AGPL_3',
   "GNU (?:general )?public license,? $_v?([123])" => sub { "GPL_$_[0]" },
   'GNU (?:general )?public license'             => [ map {"GPL_$_"} (1..3) ],
@@ -83,7 +83,7 @@ sub guess_license_from_pod {
 	return;
 }
 
-my %yaml_keys = (
+my %meta_keys = (
   perl         => 'Perl_5',
   apache       => [ map { "Apache_$_" } qw(1_1 2_0) ],
   artistic     => 'Artistic_1_0',
@@ -111,7 +111,7 @@ sub guess_license_from_meta_yml {
 
   my ($license_text) = $yaml_text =~ m{^license: (.+)}gm;
 
-  return unless $license_text and my $license = $yaml_keys{ $license_text };
+  return unless $license_text and my $license = $meta_keys{ $license_text };
 
   return map { "Software::License::$_" } ref $license ? @$license : $license;
 }
